@@ -20,11 +20,7 @@
 # IN THE SOFTWARE.
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.1.1'
+__version__ = '1.0.0'
 
-from . import abc
 from .chaindict import ChainDict
-from .hashdict import HashDict
-from .lambdadict import LambdaDict
-from .ordereddict import OrderedDict
 from .orderedset import OrderedSet
